import axios, {type InternalAxiosRequestConfig, type AxiosResponse} from 'axios';
import {ResultEnum} from "@/enums/ResultEnum";

const service = axios.create({
	baseURL: import.meta.env.VITE_APP_BASE_API,
	timeout: 50000,
	headers: { 'Content-Type': 'application/json;charset=utf-8' }
});

// 请求拦截器
service.interceptors.request.use((config:InternalAxiosRequestConfig)=>{
	return config;
},(error:any)=>{
	return Promise.reject(error);
});

// 响应拦截器
service.interceptors.response.use((response: AxiosResponse)=>{
	const {code, data, msg } = response.data;
	if(code === ResultEnum.SUCCESS) {
		return data;
	}
	return Promise.reject(new Error(msg || "Error"));
}, (error: any)=>{
	return Promise.reject(error);
});

export default service;
